@@ -1,7 +1,7 @@
 use strict;
 package Dist::Zilla::PluginBundle::Author::MAXHQ;
 # ABSTRACT: MAXHQ's default Dist::Zilla configuration
-$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '2.002000';
+$Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '2.002001';
 #pod =encoding UTF-8
 #pod
 #pod =head1 SYNOPSIS
@@ -32,17 +32,18 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '2.002000';
 #pod Currently this plugin bundle is equivalent to:
 #pod
 #pod 	#
-#pod 	# Files included
+#pod 	# Include files tracked by Git with some exceptions
 #pod 	#
-#pod 	[GatherDir]
+#pod 	[Git::GatherDir]
+#pod 	exclude_match = ^cpanfile.snapshot$
 #pod 	exclude_match = \A[^\/]+\.ini\Z
 #pod 	exclude_match = \A[^\/]+\.tar\.gz\Z
-#pod 	prune_directory = ^\.build$
-#pod 	prune_directory = ^\.git$
-#pod 	prune_directory = ^\.svn$
-#pod 	prune_directory = ^extlib$
-#pod 	prune_directory = ^local$
-#pod 	prune_directory = ^CVS$
+#pod 	exclude_match = ^\.build\b
+#pod 	exclude_match = ^\.git\b
+#pod 	exclude_match = ^\.svn\b
+#pod 	exclude_match = ^extlib\b
+#pod 	exclude_match = ^local\b
+#pod 	exclude_match = ^CVS\b
 #pod 	include_dotfiles = 1
 #pod
 #pod 	[PruneCruft]
@@ -101,6 +102,7 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '2.002000';
 #pod 	#
 #pod 	[ModuleBuild]
 #pod 	[MetaYAML]
+#pod 	[MetaJSON]
 #pod 	[Manifest]
 #pod 	[License]
 #pod 	[ReadmeAnyFromPod]
@@ -117,12 +119,6 @@ $Dist::Zilla::PluginBundle::Author::MAXHQ::VERSION = '2.002000';
 #pod 	[Test::Pod::LinkCheck]
 #pod
 #pod 	#
-#pod 	# Auto generation --- docs
-#pod 	#
-#pod 	[Pod2Html]
-#pod 	dir = doc
-#pod
-#pod 	#
 #pod 	# Release
 #pod 	#
 #pod 	[TestRelease]
@@ -205,8 +201,15 @@ sub configure {
 		@{ $self->payload->{'GatherDir.exclude_match'} || [] },
 		# ...with the default options (exclude certain files at top level)
 		qw(
-			\A[^\/]+\.ini\Z
-			\A[^\/]+\.tar\.gz\Z
+			^cpanfile.snapshot$
+			^\w+\.ini$
+			^\w+\.tar\.gz$
+			^extlib\b
+			^local\b
+			^\.build\b
+			^\.git\b
+			^\.svn\b
+			^CVS\b
 		)
 	);
 
@@ -214,10 +217,9 @@ sub configure {
 		#
 		# Files included
 		#
-		['GatherDir' => {                 # skip files on top level
-			exclude_match => \@exclude_matches,
-			prune_directory => ['\Aextlib\Z', '\Alocal\Z', '\A\.build\Z', '\A\.git\Z', '\A\.svn\Z', '\ACVS\Z'],
-			include_dotfiles => 1, # needed e.g. for ".devdir"
+		['Git::GatherDir' => {                 # skip files on top level
+			exclude_match => [ @exclude_matches ],
+			include_dotfiles => 1, # needed e.g. for ".devdir",
 		}],
 		'PruneCruft',                     # prune stuff you probably don't want
 
@@ -288,7 +290,8 @@ sub configure {
 		# Auto generation --- distribution files
 		#
 		'ModuleBuild',                    # build a Build.PL that uses Module::Build to install the distribution
-		'MetaYAML',                       # generate META.yml
+		'MetaYAML',                       # generate META.yml (supports CPAN::Meta::Spec v1.4)
+		'MetaJSON',                       # generate META.json (supports CPAN::Meta::Spec v2.0 upwards)
 		'Manifest',                       # generate Manifest (list of all files)
 		'License',                        # generate LICENSE
 		'ReadmeAnyFromPod',               # generate README (with dist's name, version, abstract, license)
@@ -306,13 +309,6 @@ sub configure {
 		'Test::Pod::No404s',
 		'Test::Pod::LinkCheck',
 
-		#
-		# Auto generation --- docs
-		#
-		['Pod2Html' => {                  # generate HTML documentation
-			'dir' => 'doc',
-		}],
-
 		#
 		# Release
 		#
@@ -338,7 +334,7 @@ __PACKAGE__->meta->make_immutable;
 {
 	package Dist::Zilla::Plugin::ShareDir::ProjectDistDir;
 	# ABSTRACT: install a directory's contents as "ShareDir" content
-$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '2.002000';
+$Dist::Zilla::Plugin::ShareDir::ProjectDistDir::VERSION = '2.002001';
 use Moose;
 	use namespace::autoclean;
 
@@ -386,7 +382,7 @@ Dist::Zilla::PluginBundle::Author::MAXHQ - MAXHQ's default Dist::Zilla configura
 
 =head1 VERSION
 
-version 2.002000
+version 2.002001
 
 =head1 SYNOPSIS
 
@@ -422,17 +418,18 @@ C<nodoc> - Set this to 1 to prevent the generation of HTML documents under doc/
 Currently this plugin bundle is equivalent to:
 
 	#
-	# Files included
+	# Include files tracked by Git with some exceptions
 	#
-	[GatherDir]
+	[Git::GatherDir]
+	exclude_match = ^cpanfile.snapshot$
 	exclude_match = \A[^\/]+\.ini\Z
 	exclude_match = \A[^\/]+\.tar\.gz\Z
-	prune_directory = ^\.build$
-	prune_directory = ^\.git$
-	prune_directory = ^\.svn$
-	prune_directory = ^extlib$
-	prune_directory = ^local$
-	prune_directory = ^CVS$
+	exclude_match = ^\.build\b
+	exclude_match = ^\.git\b
+	exclude_match = ^\.svn\b
+	exclude_match = ^extlib\b
+	exclude_match = ^local\b
+	exclude_match = ^CVS\b
 	include_dotfiles = 1
 
 	[PruneCruft]
@@ -491,6 +488,7 @@ Currently this plugin bundle is equivalent to:
 	#
 	[ModuleBuild]
 	[MetaYAML]
+	[MetaJSON]
 	[Manifest]
 	[License]
 	[ReadmeAnyFromPod]
@@ -506,12 +504,6 @@ Currently this plugin bundle is equivalent to:
 	[Test::Pod::No404s]
 	[Test::Pod::LinkCheck]
 
-	#
-	# Auto generation --- docs
-	#
-	[Pod2Html]
-	dir = doc
-
 	#
 	# Release
 	#
